@@ -58,7 +58,7 @@ ansi_escape_sequence = re.compile(r"(\x1b[@-Z\\-~]|\x1b\[.*?[@-~]|\x9b.*?[@-~])"
 special_optional_regex = (
     "py2|long time|not implemented|not tested|optional|needs|known bug"
 )
-tag_with_explanation_regex = r"((?:\w|[.])*)\s*(?:\((?P<cmd_explanation>.*?)\))?"
+tag_with_explanation_regex = r"((?:!?\w|[.])*)\s*(?:\((?P<cmd_explanation>.*?)\))?"
 optional_regex = re.compile(
     rf"[^ a-z]\s*(?P<cmd>{special_optional_regex})(?:\s|[:-])*(?P<tags>(?:(?:{tag_with_explanation_regex})\s*)*)",
     re.IGNORECASE,
@@ -991,6 +991,7 @@ class SageDocTestParser(doctest.DocTestParser):
 
         TESTS::
 
+            sage: # needs sage.combinat
             sage: parse("::\n\n    sage: # needs sage.combinat\n    sage: from sage.geometry.polyhedron.combinatorial_polyhedron.conversions \\\n    ....:         import incidence_matrix_to_bit_rep_of_Vrep\n    sage: P = polytopes.associahedron(['A',3])\n\n")
             ['::\n\n',
             '',
@@ -1124,14 +1125,14 @@ class SageDocTestParser(doctest.DocTestParser):
                             continue
 
                     if self.optional_tags is not True:
-                        extra = {
-                            tag
-                            for tag in optional_tags
-                            if (
-                                tag not in self.optional_tags
-                                and tag not in available_software
-                            )
-                        }
+                        extra = set()
+                        for tag in optional_tags:
+                            if tag not in self.optional_tags:
+                                if tag.startswith('!'):
+                                    if tag[1:] in available_software:
+                                        extra.add(tag)
+                                elif tag not in available_software:
+                                    extra.add(tag)
                         if extra and any(tag in ["bug"] for tag in extra):
                             # Bug only occurs on a specific platform?
                             bug_platform = optional_tags_with_values.get("bug")
@@ -1287,6 +1288,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(rndstr,nf,optflag)
             True
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(tentol,nf,optflag)
             True
             sage: OC.check_output(tentol,ten,optflag)
@@ -1294,6 +1296,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(tentol,zero,optflag)
             False
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(tenabs,nf,optflag)
             False
             sage: OC.check_output(tenabs,ten,optflag)
@@ -1301,6 +1304,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(tenabs,zero,optflag)
             False
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(tenrel,nf,optflag)
             True
             sage: OC.check_output(tenrel,ten,optflag)
@@ -1308,6 +1312,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(tenrel,zero,optflag)
             False
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(zerotol,zero,optflag)
             True
             sage: OC.check_output(zerotol,eps,optflag)
@@ -1315,6 +1320,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(zerotol,ten,optflag)
             False
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(zeroabs,zero,optflag)
             True
             sage: OC.check_output(zeroabs,eps,optflag)
@@ -1322,6 +1328,7 @@ class SageOutputChecker(doctest.OutputChecker):
             sage: OC.check_output(zeroabs,ten,optflag)
             False
 
+            sage: # needs sage.rings.real_interval_field
             sage: OC.check_output(zerorel,zero,optflag)
             True
             sage: OC.check_output(zerorel,eps,optflag)
@@ -1331,6 +1338,7 @@ class SageOutputChecker(doctest.OutputChecker):
 
         More explicit tolerance checks::
 
+            sage: # needs sage.rings.real_interval_field
             sage: _ = x  # rel tol 1e10                                                 # needs sage.symbolic
             sage: raise RuntimeError   # rel tol 1e10
             Traceback (most recent call last):
@@ -1347,11 +1355,13 @@ class SageOutputChecker(doctest.OutputChecker):
 
         Abs tol checks over the complex domain::
 
+            sage: # needs sage.rings.real_interval_field sage.symbolic
             sage: [1, -1.3, -1.5 + 0.1*I, 0.5 - 0.1*I, -1.5*I]  # abs tol 1.0
             [1, -1, -1, 1, -I]
 
         Spaces before numbers or between the sign and number are ignored::
 
+            sage: # needs sage.rings.real_interval_field
             sage: print("[ - 1, 2]")  # abs tol 1e-10
             [-1,2]
 
@@ -1520,8 +1530,17 @@ class SageOutputChecker(doctest.OutputChecker):
             did_fixup = True
 
         if "ld_classic is deprecated" in got:
-            ld_classic_warning_regex = re.compile(r'ld: warning: -ld_classic is deprecated and will be removed in a future release')
-            got = ld_classic_warning_regex.sub('', got)
+            # New warnings as of Oct '24, Xcode 16.
+            ld_warn_regex = re.compile("ld: warning: -ld_classic is deprecated and will be removed in a future release")
+            got = ld_warn_regex.sub('', got)
+            did_fixup = True
+
+        if "duplicate libraries" in got:
+            # New warnings as of Sept '23, OS X 13.6, new command-line
+            # tools. In particular, these seem to come from ld in
+            # Xcode 15.
+            dup_lib_regex = re.compile("ld: warning: ignoring duplicate libraries: .*")
+            got = dup_lib_regex.sub('', got)
             did_fixup = True
 
         return did_fixup, want, got
@@ -1562,6 +1581,7 @@ class SageOutputChecker(doctest.OutputChecker):
 
         ::
 
+            sage: # needs sage.rings.real_interval_field
             sage: print(OC.output_difference(tenabs,nf,optflag))
             Expected:
                 10.0
@@ -1569,7 +1589,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 9.5
             Tolerance exceeded:
                 10.0 vs 9.5, tolerance 5e-1 > 1e-1
-
             sage: print(OC.output_difference(tentol,zero,optflag))
             Expected:
                 10.0
@@ -1577,7 +1596,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 0.0
             Tolerance exceeded:
                 10.0 vs 0.0, tolerance 1e0 > 1e-1
-
             sage: print(OC.output_difference(tentol,eps,optflag))
             Expected:
                 10.0
@@ -1585,7 +1603,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 -0.05
             Tolerance exceeded:
                 10.0 vs -0.05, tolerance 2e0 > 1e-1
-
             sage: print(OC.output_difference(tlist,L,optflag))
             Expected:
                 [10.0, 10.0, 10.0, 10.0, 10.0, 10.0]
@@ -1597,6 +1614,7 @@ class SageOutputChecker(doctest.OutputChecker):
 
         TESTS::
 
+            sage: # needs sage.rings.real_interval_field
             sage: print(OC.output_difference(tenabs,zero,optflag))
             Expected:
                 10.0
@@ -1604,7 +1622,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 0.0
             Tolerance exceeded:
                 10.0 vs 0.0, tolerance 1e1 > 1e-1
-
             sage: print(OC.output_difference(tenrel,zero,optflag))
             Expected:
                 10.0
@@ -1612,7 +1629,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 0.0
             Tolerance exceeded:
                 10.0 vs 0.0, tolerance 1e0 > 1e-1
-
             sage: print(OC.output_difference(tenrel,eps,optflag))
             Expected:
                 10.0
@@ -1620,7 +1636,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 -0.05
             Tolerance exceeded:
                 10.0 vs -0.05, tolerance 2e0 > 1e-1
-
             sage: print(OC.output_difference(zerotol,ten,optflag))
             Expected:
                 0.0
@@ -1628,7 +1643,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 10.05
             Tolerance exceeded:
                 0.0 vs 10.05, tolerance 2e1 > 1e-1
-
             sage: print(OC.output_difference(zeroabs,ten,optflag))
             Expected:
                 0.0
@@ -1636,7 +1650,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 10.05
             Tolerance exceeded:
                 0.0 vs 10.05, tolerance 2e1 > 1e-1
-
             sage: print(OC.output_difference(zerorel,eps,optflag))
             Expected:
                 0.0
@@ -1644,7 +1657,6 @@ class SageOutputChecker(doctest.OutputChecker):
                 -0.05
             Tolerance exceeded:
                 0.0 vs -0.05, tolerance +infinity > 1e-1
-
             sage: print(OC.output_difference(zerorel,ten,optflag))
             Expected:
                 0.0
